summaryrefslogtreecommitdiffstats
path: root/src/disk_interface.h
diff options
context:
space:
mode:
authorPetrWolf <petr.wolf@gmail.com>2012-02-14 17:30:14 (GMT)
committerPetrWolf <petr.wolf@gmail.com>2012-02-14 17:30:14 (GMT)
commitc4fc06b0768bd30c5d93e7c1829395cc714cbfc1 (patch)
tree4b7ae5b7f4973e12839d979ca39f9b73d7056e90 /src/disk_interface.h
parentaf070e520806987bd3b175bf222774de923b62dd (diff)
downloadNinja-c4fc06b0768bd30c5d93e7c1829395cc714cbfc1.zip
Ninja-c4fc06b0768bd30c5d93e7c1829395cc714cbfc1.tar.gz
Ninja-c4fc06b0768bd30c5d93e7c1829395cc714cbfc1.tar.bz2
Fix tabs, typos
Diffstat (limited to 'src/disk_interface.h')
-rw-r--r--src/disk_interface.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/disk_interface.h b/src/disk_interface.h
index 04e64ec..c0f5ee5 100644
--- a/src/disk_interface.h
+++ b/src/disk_interface.h
@@ -34,9 +34,9 @@ struct DiskInterface {
/// Create a directory, returning false on failure.
virtual bool MakeDir(const string& path) = 0;
/// Create a file, with the specified name and contens
/// Returns true on success, false on failure
- virtual bool WriteFile(const string & path, const string & contetns) = 0;
+ virtual bool WriteFile(const string & path, const string & contents) = 0;
/// Read a file to a string. Fill in |err| on error.
virtual string ReadFile(const string& path, string* err) = 0;
@@ -58,7 +58,7 @@ struct RealDiskInterface : public DiskInterface {
virtual ~RealDiskInterface() {}
virtual TimeStamp Stat(const string& path);
virtual bool MakeDir(const string& path);
- virtual bool WriteFile(const string & path, const string & contens);
+ virtual bool WriteFile(const string & path, const string & contents);
virtual string ReadFile(const string& path, string* err);
virtual int RemoveFile(const string& path);
};
@@ -34,9 +34,9 @@ struct DiskInterface {
/// Create a directory, returning false on failure.
virtual bool MakeDir(const string& path) = 0;
- /// Create a file, with the specified name and contens
+ /// Create a file, with the specified name and contents
/// Returns true on success, false on failure